// -----------------------------------------------------------------------------
//
//   MODELS: Grass models in Wavefront OBJ format.
//   AUTHOR: Julius aka Julio César (juliocesar2k7@gmail.com)
//
// TEXTURES: Grass #1, Grass #2 and Grass #3 texture packs.
//   AUTHOR: Nobiax (CC0 1.0 Universal)
//
//
// - All textures are edited to boost the overall light and to get rid of
//   near-black parts of the images.
//
// - Shaders written by Julius, 22-Jan-2018
//
// -----------------------------------------------------------------------------
//
// VERTEX LIT:
//
//  VERTEX LIGHTING method calculates illumination at each vertex of a 3D model
//  (at compile time) and then interpolates the resulting values over the model's
//  faces to calculate the final per-pixel color values (Gouraud shading, during
//  rendering).
//
//
//  surfaceparm pointlight         // vertex-lit, same as "surfaceparm nolightmap"
//  q3map_vertexScale N.N          // used to lighten or darken a vertex-lit surface
//                                    (does not work with rgbGen exactVertex)
//  {
//    ...
//    rgbGen vertex
//  }
//
//
// Remarks:
//
//  - Vertex-lit surfaces are FASTER to render because no lightmaps are used.
//  - No lightmaps means NO SHADOWS ARE CAST ON vertex-lit surfaces.
//  - Anything related to Pixel-based lighting and/or lightmaps is IGNORED or
//    simply DOES NOT APPLY:
//
//     normal/gloss maps, Ambient Occlusion (-dirt compile parm).
//
//  - Bounced light (Radiosity) and Phong Shading works.
//
//  ALL the above has been TESTED on 13-Jan-2018 (julius).
//
// -----------------------------------------------------------------------------

// -----------------------------------------------------------------------------
// GRASS (double-sided models)
// -----------------------------------------------------------------------------

// Grass 1

textures/jul_grass/grass1_VLIT
{
    qer_editorImage models/jul_grass/grass1.tga
    qer_alphaFunc gequal 0.5

    //q3map_vertexScale 1.5             // light multiplier

    surfaceparm trans
    surfaceparm alphashadow
    surfaceparm pointlight

    {
        map models/jul_grass/grass1.tga
        rgbGen vertex
        alphaFunc GT0
    }
}

// Grass 2

textures/jul_grass/grass2_VLIT
{
    qer_editorImage models/jul_grass/grass2.tga
    qer_alphaFunc gequal 0.5

    //q3map_vertexScale 1.5

    surfaceparm trans
    surfaceparm alphashadow
    surfaceparm pointlight

    {
        map models/jul_grass/grass2.tga
        rgbGen vertex
        alphaFunc GT0
    }
}

// Grass 3

textures/jul_grass/grass3_VLIT
{
    qer_editorImage models/jul_grass/grass3.tga
    qer_alphaFunc gequal 0.5

    //q3map_vertexScale 1.5

    surfaceparm trans
    surfaceparm alphashadow
    surfaceparm pointlight

    {
        map models/jul_grass/grass3.tga
        rgbGen vertex
        alphaFunc GT0
    }
}

// Grass 4

textures/jul_grass/grass4_VLIT
{
    qer_editorImage models/jul_grass/grass4.tga
    qer_alphaFunc gequal 0.5

    //q3map_vertexScale 1.5

    surfaceparm trans
    surfaceparm alphashadow
    surfaceparm pointlight

    {
        map models/jul_grass/grass4.tga
        rgbGen vertex
        alphaFunc GT0
    }
}

// Grass 5

textures/jul_grass/grass5_VLIT
{
    qer_editorImage models/jul_grass/grass5.tga
    qer_alphaFunc gequal 0.5

    //q3map_vertexScale 1.5

    surfaceparm trans
    surfaceparm alphashadow
    surfaceparm pointlight

    {
        map models/jul_grass/grass5.tga
        rgbGen vertex
        alphaFunc GT0
    }
}

// Grass 6

textures/jul_grass/grass6_VLIT
{
    qer_editorImage models/jul_grass/grass6.tga
    qer_alphaFunc gequal 0.5

    //q3map_vertexScale 1.5

    surfaceparm trans
    surfaceparm alphashadow
    surfaceparm pointlight

    {
        map models/jul_grass/grass6.tga
        rgbGen vertex
        alphaFunc GT0
    }
}

// Grass 7

textures/jul_grass/grass7_VLIT
{
    qer_editorImage models/jul_grass/grass7.tga
    qer_alphaFunc gequal 0.5

    //q3map_vertexScale 1.5

    surfaceparm trans
    surfaceparm alphashadow
    surfaceparm pointlight

    {
        map models/jul_grass/grass7.tga
        rgbGen vertex
        alphaFunc GT0
    }
}

// EOF ------------------------------- EOF --------------------------------- EOF
